@@ -3,14 +3,13 @@ tests = r"""
 >>> from django.forms import *
 >>> from django.forms.widgets import RadioFieldRenderer
 >>> from django.utils.safestring import mark_safe
->>> from django.utils.encoding import force_unicode
+>>> from django.utils import formats
 >>> import datetime
 >>> import time
 >>> import re
->>> try:
-...     from decimal import Decimal
-... except ImportError:
-...     from django.utils._decimal import Decimal
+>>> from decimal import Decimal
+>>> from django.utils.translation import activate, deactivate
+>>> from django.conf import settings
 
 ###########
 # Widgets #
@@ -1110,6 +1109,13 @@ True
 False
 >>> w._has_changed(datetime.datetime(2008, 5, 6, 12, 40, 00), [u'06/05/2008', u'12:41'])
 True
+>>> activate('de-at')
+>>> settings.USE_L10N = True
+>>> w._has_changed(datetime.datetime(2008, 5, 6, 12, 40, 00), [u'06.05.2008', u'12:41'])
+True
+>>> deactivate()
+>>> settings.USE_L10N = False
+
 
 # DateTimeInput ###############################################################
 
@@ -1127,6 +1133,12 @@ u'<input type="text" name="date" value="2007-09-17 12:51:34" />'
 u'<input type="text" name="date" value="2007-09-17 12:51:34" />'
 >>> w.render('date', datetime.datetime(2007, 9, 17, 12, 51))
 u'<input type="text" name="date" value="2007-09-17 12:51:00" />'
+>>> activate('de-at')
+>>> settings.USE_L10N = True
+>>> w.render('date', d)
+u'<input type="text" name="date" value="17.09.2007 12:51:34" />'
+>>> deactivate()
+>>> settings.USE_L10N = False
 
 Use 'format' to change the way a value is displayed.
 >>> w = DateTimeInput(format='%d/%m/%Y %H:%M')
@@ -1136,11 +1148,11 @@ u'<input type="text" name="date" value="17/09/2007 12:51" />'
 False
 
 Make sure a custom format works with _has_changed. The hidden input will use
-force_unicode to display the initial value.
+format.localize_input to display the initial value.
 >>> data = datetime.datetime(2010, 3, 6, 12, 0, 0)
 >>> custom_format = '%d.%m.%Y %H:%M'
 >>> w = DateTimeInput(format=custom_format)
->>> w._has_changed(force_unicode(data), data.strftime(custom_format))
+>>> w._has_changed(formats.localize_input(data), data.strftime(custom_format))
 False
 
 
@@ -1162,6 +1174,13 @@ We should be able to initialize from a unicode value.
 >>> w.render('date', u'2007-09-17')
 u'<input type="text" name="date" value="2007-09-17" />'
 
+>>> activate('de-at')
+>>> settings.USE_L10N = True
+>>> w.render('date', d)
+u'<input type="text" name="date" value="17.09.2007" />'
+>>> deactivate()
+>>> settings.USE_L10N = False
+
 Use 'format' to change the way a value is displayed.
 >>> w = DateInput(format='%d/%m/%Y')
 >>> w.render('date', d)
@@ -1170,11 +1189,11 @@ u'<input type="text" name="date" value="17/09/2007" />'
 False
 
 Make sure a custom format works with _has_changed. The hidden input will use
-force_unicode to display the initial value.
+format.localize_input to display the initial value.
 >>> data = datetime.date(2010, 3, 6)
 >>> custom_format = '%d.%m.%Y'
 >>> w = DateInput(format=custom_format)
->>> w._has_changed(force_unicode(data), data.strftime(custom_format))
+>>> w._has_changed(formats.localize_input(data), data.strftime(custom_format))
 False
 
 
@@ -1199,6 +1218,13 @@ We should be able to initialize from a unicode value.
 >>> w.render('time', u'13:12:11')
 u'<input type="text" name="time" value="13:12:11" />'
 
+>>> activate('de-at')
+>>> settings.USE_L10N = True
+>>> w.render('date', d)
+u'<input type="text" name="date" value="17.09.2007" />'
+>>> deactivate()
+>>> settings.USE_L10N = False
+
 Use 'format' to change the way a value is displayed.
 >>> w = TimeInput(format='%H:%M')
 >>> w.render('time', t)
@@ -1207,11 +1233,11 @@ u'<input type="text" name="time" value="12:51" />'
 False
 
 Make sure a custom format works with _has_changed. The hidden input will use
-force_unicode to display the initial value.
+format.localize_input to display the initial value.
 >>> data = datetime.time(13, 0)
 >>> custom_format = '%I:%M %p'
 >>> w = TimeInput(format=custom_format)
->>> w._has_changed(force_unicode(data), data.strftime(custom_format))
+>>> w._has_changed(formats.localize_input(data), data.strftime(custom_format))
 False
 
 
@@ -1231,6 +1257,12 @@ u'<input type="hidden" name="date_0" value="2007-09-17" /><input type="hidden" n
 u'<input type="hidden" name="date_0" value="2007-09-17" /><input type="hidden" name="date_1" value="12:51:34" />'
 >>> w.render('date', datetime.datetime(2007, 9, 17, 12, 51))
 u'<input type="hidden" name="date_0" value="2007-09-17" /><input type="hidden" name="date_1" value="12:51:00" />'
+>>> activate('de-at')
+>>> settings.USE_L10N = True
+>>> w.render('date', datetime.datetime(2007, 9, 17, 12, 51))
+u'<input type="hidden" name="date_0" value="17.09.2007" /><input type="hidden" name="date_1" value="12:51:00" />'
+>>> deactivate()
+>>> settings.USE_L10N = False
 
 """
 
